package com.bwie.server.config;

import com.alibaba.fastjson.JSON;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.bwie.common.domain.InterestRate;
import com.bwie.server.mapper.InterestRateMapper;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.data.redis.core.StringRedisTemplate;

import javax.annotation.Resource;
import java.util.List;

/**
 * Description:
 *
 * @Author: sun-cool-boy
 * @Date: 2023/10/10
 * @info: 初始化数据
 */
@Configuration
public class InitData {

    /**
     * 注入redis
     */
    @Resource
    private StringRedisTemplate stringRedisTemplate;

    /**
     * 注入利率持久层
     */
    @Resource
    private InterestRateMapper interestRateMapper;

    /**
     * 项目启动同步将利率存入redis
     */
    @Bean
    public void syncInterestRate(){
        //初始化前先删除旧数据
        if (stringRedisTemplate.hasKey(RedisMeta.INTEREST_RATE_INFO)){
            stringRedisTemplate.delete(RedisMeta.INTEREST_RATE_INFO);
        }
        //填入更新数据
        List<InterestRate> interestRates = interestRateMapper.selectList(new QueryWrapper<>());
        interestRates.forEach(obj -> {
            stringRedisTemplate.opsForList().rightPush(RedisMeta.INTEREST_RATE_INFO, JSON.toJSONString(obj));
        });
    }


}
